facepunch commits
Flavien
2 Hours Ago
rust_reboot
/main/more_lod_optims
#169597
Optimised RendererGroup invalidation, only the combined mesh holding the block is switched back to separate renderers Editor profiling, walking around the same big base: slowest LOD switch ~2.5ms -> ~1ms
thumb_up
1
thumb_down
0